Dear user, this package provides the vim addon disources, but it is not enabled
per default.

If you want to enable it for your user account just execute

	vim-addons install disources

Similarly, to enable it for all users of this system just execute (as root):

	vim-addons -w install disources

vim-addons is provided by the vim-addon-manager package, have a look at its
manpage for more information.

